/* (C) 2022 YiRing, Inc. */
package com.yiring.app.domain.car;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.yiring.common.annotation.Excel;
import java.io.Serializable;
import java.time.LocalDateTime;
import javax.persistence.*;
import lombok.*;
import lombok.experimental.FieldDefaults;
import lombok.experimental.FieldNameConstants;
import org.hibernate.annotations.Comment;
import org.hibernate.annotations.GenericGenerator;
import org.hibernate.snowflake.SnowflakeId;

/**
 * @author tzl
 * 2022/4/11 13:38
 */
@Getter
@Setter
@ToString
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldNameConstants
@FieldDefaults(level = AccessLevel.PRIVATE)
@Entity
@Table(name = "BS_CAR")
@Comment("车辆")
public class Car implements Serializable {

    @Id
    @Comment("主键id")
    @GeneratedValue(generator = SnowflakeId.GENERATOR)
    @GenericGenerator(name = SnowflakeId.GENERATOR, strategy = SnowflakeId.Strategy.LONG)
    Long id;

    @Comment("车牌号")
    @Excel(name = "车牌", sort = 1)
    String carNum;

    @Comment("车辆类型")
    @Excel(name = "车辆类型", sort = 2, dictType = "car_type")
    String carType;

    @Comment("司机名称")
    @Excel(name = "司机", sort = 3)
    String driverName;

    @Comment("司机电话")
    @Excel(name = "联系电话", sort = 4)
    String driverMobile;

    @Comment("标签卡")
    @Excel(name = "标签卡", sort = 9)
    String labelCard;

    @Comment("标签卡状态")
    @Excel(name = "标签卡状态", sort = 10, dictType = "car_label_status")
    String labelCardStatus;

    @Comment("所属单位id")
    @Excel(name = "所属单位", sort = 5)
    String orgId;

    @Comment("被访人id")
    @Excel(name = "被访人", sort = 7)
    String intervieweeId;

    @Comment("来访原因")
    @Excel(name = "来访原因", sort = 6)
    String reason;

    @Comment("收卡时间")
    @Excel(name = "收卡时间", sort = 11, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardRecTime;

    @Comment("创建时间")
    @Excel(name = "到访时间", sort = 8, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime createTime;

    @Comment("发卡时间")
    LocalDateTime cardSendTime;

    @Comment("备用字段")
    String reserve4;
}
