/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.video;

import com.yiring.app.param.video.VideoParam;
import com.yiring.app.param.video.VideoQueryParam;
import com.yiring.app.vo.video.VideoVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import java.awt.*;
import org.locationtech.jts.geom.Point;

/**
 * @author tzl
 * 2022/4/8 15:28
 */
public interface VideoService {
    /**
     * 监控视频点位添加
     *
     * @param videoParam VideoParam
     * @return Result<String>
     * @author tzl
     * @date 2022/4/8 16:23
     */
    Result<String> saveVideo(VideoParam videoParam);

    /**
     * 删除监控点位信息
     * @param idParam 主键id
     * @return Result<String>
     * @author tzl
     * @date 2022/4/15 10:16
     */
    Result<String> deleteVideo(IdParam idParam);

    /**
     * 修改监控点位信息
     * @param videoParam 修改的参数
     * @param idParam    主键id
     * @return Result<String>
     * @author tzl
     * @date 2022/4/15 10:19
     */
    Result<String> updateVideo(VideoParam videoParam, IdParam idParam);

    /**
     * 查询监控点坐标
     * @param idParam 主键id
     * @return Result<Point> 坐标信息
     * @author tzl
     * @date 2022/4/15 14:15
     */
    Result<Point> selectPoint(IdParam idParam);

    /**
     * 分页查询
     * @param videoQueryParam 筛选条件
     * @param param  分页参数
     * @return Result<PageVo<VideoVo>> 分页结果集
     * @author tzl
     * @date 2022/4/15 14:35
     */
    Result<PageVo<VideoVo>> pageVideo(VideoQueryParam videoQueryParam, PageParam param);
}
