/* (C) 2022 YiRing, Inc. */
package com.yiring.app.vo.car;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import com.yiring.common.util.DictUtils;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.*;
import lombok.experimental.FieldDefaults;
import org.apache.commons.lang3.StringUtils;

/**
 * @author tzl
 * 2022/4/11 14:52
 */
@ApiModel("CarVo")
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
@FieldDefaults(level = AccessLevel.PRIVATE)
public class CarVo implements Serializable {

    @JsonSerialize(using = ToStringSerializer.class)
    @ApiModelProperty(value = "主键id", example = "1458555485552")
    Long id;

    @ApiModelProperty(value = "车牌号码", example = "湘A99999")
    String carNum;

    @ApiModelProperty(value = "车辆类型", example = "1")
    String carType;

    /**
     * 车辆类型翻译
     */
    @ApiModelProperty(value = "车辆类型(字典翻译)", example = "货车")
    String carTypeName;

    public String getCarTypeName() {
        if (StringUtils.isNotBlank(carType)) {
            return DictUtils.getDictLabel("car_type", carType);
        }
        return null;
    }

    @ApiModelProperty(value = "司机名称", example = "张三")
    String driverName;

    @ApiModelProperty(value = "司机电话", example = "17688888888")
    String driverMobile;

    @ApiModelProperty(value = "标签卡", example = "DT8875666")
    String labelCard;

    @ApiModelProperty(value = "标签卡状态", example = "1")
    String labelCardStatus;

    /**
     * 车辆类型翻译
     */
    @ApiModelProperty(value = "标签卡状态", example = "未发卡")
    String labelCardStatusName;

    public String getLabelCardStatusName() {
        if (StringUtils.isNotBlank(carType)) {
            return DictUtils.getDictLabel("car_label_status", labelCardStatus);
        }
        return null;
    }

    @ApiModelProperty(value = "单位id", example = "湖南壹润科技")
    String orgId;

    @ApiModelProperty(value = "被访人id", example = "1")
    String intervieweeId;

    @ApiModelProperty(value = "来访原因", example = "装货")
    String reason;

    @ApiModelProperty(value = "收卡时间", example = "2022-04-11 17:25:33")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardRecTime;

    @ApiModelProperty(value = "创建时间", example = "2022-04-11 17:25:33")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime createTime;

    @ApiModelProperty(value = "发卡时间", example = "2022-04-11 17:25:33")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    LocalDateTime cardSendTime;
}
