/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.car;

import com.yiring.app.domain.car.Car;
import com.yiring.app.param.car.CarParam;
import com.yiring.app.param.car.CarQueryParam;
import com.yiring.app.service.car.CarService;
import com.yiring.app.vo.car.CarVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.util.poi.ExcelUtils;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiOperation;
import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

/**
 * 车辆来访信息控制器
 *
 * @author tzl
 * 2022/4/11 17:02
 */
@Slf4j
@Api(tags = "Car")
@Validated
@RestController
@RequestMapping("/Car/")
public class CarController {

    @Resource
    CarService carService;

    @ApiOperation(value = "新增车辆来访信息")
    @PostMapping("saveCarInfo")
    public Result<Long> saveCarInfo(@Valid CarParam carParam) {
        return carService.saveCarInfo(carParam);
    }

    @ApiOperation(value = "修改车辆来访信息")
    @PostMapping("updateCarInfo")
    public Result<Long> updateCarInfo(@Valid CarParam carParam, @Valid IdParam idParam) {
        return carService.updateCarInfo(carParam, idParam);
    }

    @ApiOperation(value = "收卡")
    @PostMapping("cardRec")
    public Result<Long> cardRec(@Valid IdParam idParam) {
        return carService.cardRec(idParam);
    }

    @ApiOperation(value = "发卡")
    @ApiImplicitParam(value = "标签卡", example = "DW8544568", required = true, name = "labelCard")
    @PostMapping("cardSend")
    public Result<Long> cardSend(@Valid IdParam idParam, String labelCard) {
        return carService.cardSend(idParam, labelCard);
    }

    @ApiOperation(value = "删除车辆来访信息")
    @PostMapping("deleteCarInfo")
    public Result<String> deleteCarInfo(@Valid IdParam idParam) {
        return carService.deleteCarInfo(idParam);
    }

    @ApiOperation(value = "查看车辆来访信息详情")
    @GetMapping("getCarInfo")
    public Result<CarVo> getCarInfo(@Valid IdParam idParam) {
        return carService.getCarInfo(idParam);
    }

    @ApiOperation(value = "查看车辆来访信息(分页)")
    @GetMapping("pageCarInfo")
    public Result<PageVo<CarVo>> pageCarInfo(@Valid CarQueryParam carParam) {
        return carService.pageCarInfo(carParam);
    }

    @ApiOperation(value = "导出车辆来访信息")
    @PostMapping("exportCarInfo")
    public void exportCarInfo(HttpServletResponse response, @Valid CarQueryParam carParam) {
        List<Car> export = carService.export(carParam);
        ExcelUtils<Car> util = new ExcelUtils<>(Car.class);
        //        String fileName = URLEncoder.encode("车辆来访信息.xlsx", StandardCharsets.UTF_8);
        response.setContentType("application/octet-stream");
        //        response.setHeader("Content-Disposition", "attachment;filename=" + fileName);
        //        response.setCharacterEncoding("utf-8");
        util.exportExcel(response, export, "车辆来访信息");
    }
}
