/* (C) 2022 YiRing, Inc. */
package com.yiring.app.web.video;

import com.yiring.app.param.video.VideoParam;
import com.yiring.app.param.video.VideoQueryParam;
import com.yiring.app.service.video.VideoService;
import com.yiring.app.vo.video.VideoVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IdParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import javax.validation.Valid;
import lombok.extern.slf4j.Slf4j;
import org.locationtech.jts.geom.Point;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 监控点位控制器
 * @author tzl
 * 2022/4/8 16:51
 */
@Slf4j
@Validated
@Api(tags = "Video")
@RestController
@RequestMapping("/video/")
public class VideoController {

    @Resource
    VideoService videoService;

    @ApiOperation(value = "新增监控点位信息")
    @PostMapping("saveVideo")
    public Result<String> findLatest(@Valid VideoParam videoParam) {
        return videoService.saveVideo(videoParam);
    }

    @ApiOperation(value = "删除监控点位信息")
    @PostMapping("deleteVideo")
    public Result<String> deleteVideo(@Valid IdParam idParam) {
        return videoService.deleteVideo(idParam);
    }

    @ApiOperation(value = "修改监控点位信息")
    @PostMapping("updateVideo")
    public Result<String> updateVideo(@Valid VideoParam videoParam, @Valid IdParam idParam) {
        return videoService.updateVideo(videoParam, idParam);
    }

    @ApiOperation(value = "查看监控点位位置")
    @PostMapping("selectPoint")
    public Result<Point> selectPoint(@Valid IdParam idParam) {
        return videoService.selectPoint(idParam);
    }

    @ApiOperation(value = "分页查询监控点位信息")
    @PostMapping("pageVideo")
    public Result<PageVo<VideoVo>> pageVideo(@Valid VideoQueryParam videoQueryParam, @Valid PageParam param) {
        return videoService.pageVideo(videoQueryParam, param);
    }
}
